@@ -310,16 +310,15 @@ class ContainerBuilder(Container):
         return instance
 
     def get_service(self, id, definition, container):
-
-        if self.logger:
-            self.logger.debug("Get service: id=%s, class=%s" % (id, definition.clazz))
-
         if definition.abstract:
             raise ioc.exceptions.AbstractDefinitionInitialization("The ContainerBuiler try to build an abstract definition, id=%s, class=%s" % (id, definition.clazz))
 
         if container.has(id):
             return container.get(id)
 
+        # if self.logger:
+        #     self.logger.debug("Get service: id=%s, class=%s" % (id, definition.clazz))
+
         if id in self.stack:
             if self.logger:
                 self.logger.error("ioc.exceptions.CyclicReference: " + " -> ".join(self.stack) + " -> " + id)
